[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#619819: Please add some more udc devices to the g_ether section of hw-detect



Package: hw-detect
Severity: wishlist

The attached patch adds support for
- the s3c-hsudc found for example on S3C2416 based devices which will 
hopefully get into the kernel soon [1]
- the fsl-tegra-udc of the tegra platform. One example device is the Dynabook 
/ Toshiba AC100

Thanks
Heiko


[1] http://comments.gmane.org/gmane.linux.kernel.samsung-soc/4459
From 410a121ffbccbb5feac200e7023b41c279309cf5 Mon Sep 17 00:00:00 2001
From: Heiko Stuebner <heiko@sntech.de>
Date: Sat, 26 Mar 2011 22:10:31 +0100
Subject: [PATCH] Add more udc devices for g_ether networking.
 s3c-hsudc can be found on S3C2412/S3C2416/S3C64XX SoCs and
 fsl-tegra-udc as the name implies on the tegra platform.

---
 hw-detect.sh |   13 +++++++++----
 1 files changed, 9 insertions(+), 4 deletions(-)

diff --git a/hw-detect.sh b/hw-detect.sh
index f4f05df..7c19362 100755
--- a/hw-detect.sh
+++ b/hw-detect.sh
@@ -200,14 +200,19 @@ if [ -d /sys/bus/pci/devices ] && \
 	sleep 3 || true
 fi
 
 # Load the ethernet gadget network driver (g_ether) on S3C2410/S3C2440 (Openmoko GTA01/02)
 if [ -d /sys/bus/platform/devices/s3c2440-usbgadget -o \
-	-d /sys/bus/platform/devices/s3c2410-usbgadget ] ; then
-	db_subst hw-detect/load_progress_step CARDNAME "S3C2410/S3C2440 SoC"
+	-d /sys/bus/platform/devices/s3c2410-usbgadget -o \
+	-d /sys/bus/platform/devices/s3c-hsudc -o \
+	-d /sys/bus/platform/devices/fsl-tegra-udc ] ; then
+	db_subst hw-detect/load_progress_step CARDNAME "SoC USB-device-port"
 	db_subst hw-detect/load_progress_step MODULE "g_ether"
 	db_progress INFO hw-detect/load_progress_step
 	
-	log "Detected S3C2410/S3C2440 SoC, loading g_ether"
+	log "Detected SoC with USB device port, loading g_ether"
 	load_module g_ether
 	register-module g_ether
 fi
@@ -200,14 +200,19 @@ if [ -d /sys/bus/pci/devices ] && \
 fi
 
-# Load the ethernet gadget network driver (g_ether) on S3C2410/S3C2440 (Openmoko GTA01/02)
+# Load the ethernet gadget network driver (g_ether) on platforms with an udc port:
+# - S3C2410/S3C2440 (Openmoko GTA01/02)
+# - S3C2412/S3C2416 (s3c-hsudc driver)
+# - Tegra
 if [ -d /sys/bus/platform/devices/s3c2440-usbgadget -o \
-- 
1.7.2.3


Reply to: